Structs
- Execution
Info - Execution info for the current task
- Runtime
- Runtime context for graph execution
- Server
Info - Server info from LangGraph Server
Type Aliases
- Stream
Writer - StreamWriter sends custom stream chunks to the output stream.
Nodes can use this to emit arbitrary data when
stream_modeincludes “custom”.