Module runtime

Module runtime 

Structs

ExecutionInfo
Execution info for the current task
Runtime
Runtime context for graph execution
ServerInfo
Server info from LangGraph Server

Type Aliases

StreamWriter
StreamWriter sends custom stream chunks to the output stream. Nodes can use this to emit arbitrary data when stream_mode includes “custom”.